=======================
Nucleotides To Matrices
=======================


.. image:: https://img.shields.io/pypi/v/nucleotides_to_matrices.svg
        :target: https://pypi.python.org/pypi/nucleotides_to_matrices

.. image:: https://img.shields.io/travis/npdeloss/nucleotides_to_matrices.svg
        :target: https://travis-ci.com/npdeloss/nucleotides_to_matrices

.. image:: https://readthedocs.org/projects/nucleotides-to-matrices/badge/?version=latest
        :target: https://nucleotides-to-matrices.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/npdeloss/nucleotides_to_matrices/shield.svg
     :target: https://pyup.io/repos/github/npdeloss/nucleotides_to_matrices/
     :alt: Updates



Utility functions for conversion between IUPAC nucleotide codes and one-hot-like encoded sequence matrices, with extensions for RNA.


* Free software: MIT license
* Documentation: https://nucleotides-to-matrices.readthedocs.io.


Features
--------

* Conversion between strings of single-character IUPAC nucleotides and one-hot-like encodings
* Includes degenerate, gap, and RNA codes

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
